import java.util.ArrayList;

public abstract class Polygon extends Shape {
	private ArrayList<Integer> sides ;
	/**
	 * Create a new Polygon shape
	 * @param sides sides of polygon
	 */
	public Polygon(Integer... sides ) {
		this.sides = new ArrayList<Integer>() ;
		for(Integer side : sides) {
			this.sides.add(side) ;
		}
	}
	/**
	 * Get sides of Polygon
	 * @return returns sides of polygon
	 */
	public ArrayList<Integer> getSides(){
		return sides ;
	}
	@Override
	public String toString() {
		String str = this.getClass().getName() + " sides: [ " + sides.get(0) ;
		for(int i= 1 ; i<sides.size() ; i++) {
			str = str.concat(  ", " + sides.get(i)) ;
		}
		str = str.concat("]") ;
		return str ;
	}
	/**
	 * Calculate perimeter of polygon
	 */
	@Override
	public double calculatePerimeter() {
		double sum = 0 ;
		for(Integer side : sides) {
			sum += side ;
		}
		return sum ;
	}
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((sides == null) ? 0 : sides.hashCode());
		return result;
	}
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Polygon other = (Polygon) obj;
		if (sides == null) {
			if (other.sides != null)
				return false;
		} else if (!sides.equals(other.sides))
			return false;
		return true;
	}
	
}
